@@ -1,5 +1,5 @@
 assert_is_git_repo <- function(root) {
-  if (is.null(git2r::discover_repository(root))) {
+  if (!is_git_repo(root = root)) {
     rlang::abort(paste0(
       "The directory ", root, " is not a git repo. Please navigate to ",
       root, " and init git in ",
