@@ -4,12 +4,7 @@ files <- commandArgs(trailing = TRUE)
 out <- lapply(files, function(path) {
   is_rmd <- grepl("\\.[rR]md$", path)
   if (is_rmd) {
-    path_ <- knitr::purl(
-      input = path,
-      output = tempfile(fileext = ".R"),
-      quiet = TRUE,
-      documentation = FALSE
-    )
+    path_ <- precommit::robust_purl(path)
   } else {
     path_ <- path
   }
